@@ -1,5 +1,6 @@
 import ast
 import copy
+import time
 from astor import codegen
 from web.server import run_app
 from selenium import webdriver
@@ -33,13 +34,14 @@ class DemoServer(object):
 class Demo(object):
 
     def __init__(self, script_file, port=5000, browser="chrome",
-                 extra_globals=None, coords=None):
+                 extra_globals=None, coords=None, sleep=None):
         if coords is None:
             coords = {}
         if extra_globals is None:
             extra_globals = {}
         self.extra_globals = extra_globals
         self.script_file = script_file
+        self.sleep = sleep
         print "Starting demo"
         self.url = "http://localhost:%s" % port
         if browser == "chrome":
@@ -58,6 +60,8 @@ class Demo(object):
     def goto_line(self, line=1):
         self.driver.find_element_by_id("line-%s" % line)
         self.highlight_line(line)
+        if self.sleep:
+            time.sleep(self.sleep)
 
     def highlight_line(self, line):
         print "Highlighting line %s" % line
