@@ -9,6 +9,7 @@ if __name__ == "__main__":
         d = DemoServer()
         d.start_server(filepath, title="My Code", heading="My Code!")
     elif sys.argv[1] == "demo":
-        coords = {'w': 300, 'h': 200, 'x': 150, 'y': 150}
-        d = Demo(filepath, extra_globals={'MY_CONST': 'lol'}, coords=coords)
+        coords = {'w': 700, 'h': 800, 'x': 150, 'y': 0}
+        d = Demo(filepath, extra_globals={'MY_CONST': 'lol'}, coords=coords,
+                 sleep=0.75)
         d.run()
